Changelog
=========

0.0.1.dev7 (2018-11-15)
-----------------------

Adds
~~~~
End of run log message, metric


Fixes
~~~~~
* Correctly handle plugin loader errors
* Deep merge user config file when used


0.0.1.dev6 (2018-09-07)
-----------------------

Changes
~~~~~~~

Bump Gordon core version requirement


0.0.1.dev5 (2018-08-09)
-----------------------

Changes
~~~~~~~

Import plugins_loader from Gordon to obtain metrics client


0.0.1.dev3 (2018-03-22)
-----------------------

Changes
~~~~~~~

Rename interface methods.


0.0.1.dev1 (2018-02-27)
-----------------------

Changes
~~~~~~~

Initial development release.
